@@ -215,6 +215,12 @@ void ConfigDialog::initGeneralPage(QFrame* frame) {
   l->addWidget(m_cbOpenLastFile);
   connect(m_cbOpenLastFile, &QAbstractButton::clicked, this, &ConfigDialog::slotModified);
 
+  m_cbQuickFilterRegExp = new QCheckBox(i18n("&Enable regular expressions in quick filter"), frame);
+  m_cbQuickFilterRegExp->setWhatsThis(i18n("If checked, the quick filter will "
+                                           "interpret text as a regular expression."));
+  l->addWidget(m_cbQuickFilterRegExp);
+  connect(m_cbQuickFilterRegExp, &QAbstractButton::clicked, this, &ConfigDialog::slotModified);
+
   m_cbShowTipDay = new QCheckBox(i18n("&Show \"Tip of the Day\" at startup"), frame);
   m_cbShowTipDay->setWhatsThis(i18n("If checked, the \"Tip of the Day\" will be "
                                     "shown at program start-up."));
@@ -530,6 +536,15 @@ void ConfigDialog::initTemplatePage(QFrame* frame) {
   lab->setWhatsThis(whats);
   m_highTextColorCombo->setWhatsThis(whats);
 
+  lab = new QLabel(i18n("Link color:"), colGroup);
+  colLayout->addWidget(lab, ++row, 0);
+  m_linkColorCombo = new KColorCombo(colGroup);
+  colLayout->addWidget(m_linkColorCombo, row, 1);
+  connect(m_linkColorCombo, activatedInt, this, &ConfigDialog::slotModified);
+  lab->setBuddy(m_linkColorCombo);
+  lab->setWhatsThis(whats);
+  m_linkColorCombo->setWhatsThis(whats);
+
   QGroupBox* groupBox = new QGroupBox(i18n("Manage Templates"), frame);
   l->addWidget(groupBox);
   QVBoxLayout* vlay = new QVBoxLayout(groupBox);
@@ -573,6 +588,7 @@ void ConfigDialog::initTemplatePage(QFrame* frame) {
   widgets.append(m_textColorCombo);
   widgets.append(m_highBaseColorCombo);
   widgets.append(m_highTextColorCombo);
+  widgets.append(m_linkColorCombo);
   int w = 0;
   foreach(QWidget* widget, widgets) {
     widget->ensurePolished();
@@ -683,6 +699,7 @@ void ConfigDialog::readGeneralConfig() {
   m_modifying = true;
 
   m_cbShowTipDay->setChecked(Config::showTipOfDay());
+  m_cbQuickFilterRegExp->setChecked(Config::quickFilterRegExp());
   m_cbOpenLastFile->setChecked(Config::reopenLastFile());
 #ifdef ENABLE_WEBCAM
   m_cbEnableWebcam->setChecked(Config::enableWebcam());
@@ -703,7 +720,7 @@ void ConfigDialog::readGeneralConfig() {
   bool autoFormat = Config::autoFormat();
   m_cbFormat->setChecked(autoFormat);
 
-  const QRegularExpression comma(QLatin1String("\\s*,\\s*"));
+  static const QRegularExpression comma(QLatin1String("\\s*,\\s*"));
 
   m_leCapitals->setText(Config::noCapitalizationString().replace(comma, FieldFormat::delimiterString()));
   m_leArticles->setText(Config::articlesString().replace(comma, FieldFormat::delimiterString()));
@@ -741,6 +758,7 @@ void ConfigDialog::readTemplateConfig() {
   m_textColorCombo->setColor(Config::templateTextColor(collType));
   m_highBaseColorCombo->setColor(Config::templateHighlightedBaseColor(collType));
   m_highTextColorCombo->setColor(Config::templateHighlightedTextColor(collType));
+  m_linkColorCombo->setColor(Config::templateLinkColor(collType));
 
   m_modifying = false;
 }
@@ -781,6 +799,7 @@ void ConfigDialog::saveConfiguration() {
 
 void ConfigDialog::saveGeneralConfig() {
   Config::setShowTipOfDay(m_cbShowTipDay->isChecked());
+  Config::setQuickFilterRegExp(m_cbQuickFilterRegExp->isChecked());
   Config::setEnableWebcam(m_cbEnableWebcam->isChecked());
 
   int imageLocation;
@@ -797,7 +816,7 @@ void ConfigDialog::saveGeneralConfig() {
   Config::setAutoCapitalization(m_cbCapitalize->isChecked());
   Config::setAutoFormat(m_cbFormat->isChecked());
 
-  const QRegularExpression semicolon(QLatin1String("\\s*;\\s*"));
+  static const QRegularExpression semicolon(QLatin1String("\\s*;\\s*"));
   const QChar comma = QLatin1Char(',');
 
   Config::setNoCapitalizationString(m_leCapitals->text().replace(semicolon, comma));
@@ -823,6 +842,7 @@ void ConfigDialog::saveTemplateConfig() {
   Config::setTemplateTextColor(collType, m_textColorCombo->color());
   Config::setTemplateHighlightedBaseColor(collType, m_highBaseColorCombo->color());
   Config::setTemplateHighlightedTextColor(collType, m_highTextColorCombo->color());
+  Config::setTemplateLinkColor(collType, m_linkColorCombo->color());
 }
 
 void ConfigDialog::saveFetchConfig() {
@@ -1069,8 +1089,11 @@ void ConfigDialog::slotShowTemplatePreview() {
   options.textColor  = m_textColorCombo->color();
   options.highlightedTextColor = m_highTextColorCombo->color();
   options.highlightedBaseColor = m_highBaseColorCombo->color();
+  options.linkColor  = m_linkColorCombo->color();
   dlg->setXSLTOptions(Kernel::self()->collectionType(), options);
 
+  // always want to include a url to show link color too
+  bool hasLink = false;
   Data::CollPtr c = CollectionFactory::collection(Kernel::self()->collectionType(), true);
   Data::EntryPtr e(new Data::Entry(c));
   foreach(Data::FieldPtr f, c->fields()) {
@@ -1086,10 +1109,21 @@ void ConfigDialog::slotShowTemplatePreview() {
       e->setField(f->name(), QStringLiteral("true"));
     } else if(f->type() == Data::Field::Rating) {
       e->setField(f->name(), QStringLiteral("5"));
+    } else if(f->type() == Data::Field::URL) {
+      e->setField(f->name(), QStringLiteral("https://tellico-project.org"));
+      hasLink = true;
     } else {
       e->setField(f->name(), f->title());
     }
   }
+  if(!hasLink) {
+    Data::FieldPtr f(new Data::Field(QStringLiteral("url"),
+                                     QLatin1String("URL"),
+                                     Data::Field::URL));
+    f->setCategory(i18n("General"));
+    c->addField(f);
+    e->setField(f->name(), QStringLiteral("https://tellico-project.org"));
+  }
 
   dlg->showEntry(e);
   dlg->show();
