@@ -171,6 +171,7 @@ private:
   QRadioButton* m_rbImageInAppDir;
   QRadioButton* m_rbImageInLocalDir;
   QCheckBox* m_cbOpenLastFile;
+  QCheckBox* m_cbQuickFilterRegExp;
   QCheckBox* m_cbShowTipDay;
   QCheckBox* m_cbEnableWebcam;
   QCheckBox* m_cbCapitalize;
@@ -194,6 +195,7 @@ private:
   KColorCombo* m_textColorCombo;
   KColorCombo* m_highBaseColorCombo;
   KColorCombo* m_highTextColorCombo;
+  KColorCombo* m_linkColorCombo;
 
   QListWidget* m_sourceListWidget;
   QMap<FetcherInfoListItem*, Fetch::ConfigWidget*> m_configWidgets;
