@@ -25,6 +25,9 @@
 #include "colnectfetcher.h"
 #include "../collections/coincollection.h"
 #include "../collections/stampcollection.h"
+#include "../collections/comicbookcollection.h"
+#include "../collections/cardcollection.h"
+#include "../collections/gamecollection.h"
 #include "../images/imagefactory.h"
 #include "../gui/combobox.h"
 #include "../utils/guiproxy.h"
@@ -56,6 +59,7 @@ namespace {
   static const char* COLNECT_API_URL = "https://api.tellico-project.org/colnect";
 //  static const char* COLNECT_API_URL = "https://api.colnect.net";
   static const char* COLNECT_IMAGE_URL = "https://i.colnect.net";
+  static const char* COLNECT_LINK_URL = "https://colnect.com";
 }
 
 using namespace Tellico;
@@ -64,7 +68,9 @@ using Tellico::Fetch::ColnectFetcher;
 ColnectFetcher::ColnectFetcher(QObject* parent_)
     : Fetcher(parent_)
     , m_started(false)
-    , m_locale(QStringLiteral("en")) {
+    , m_locale(QStringLiteral("en"))
+    , m_imageSize(LargeImage)
+    , m_lastCollType(-1) {
 }
 
 ColnectFetcher::~ColnectFetcher() {
@@ -83,7 +89,11 @@ bool ColnectFetcher::canSearch(Fetch::FetchKey k) const {
 }
 
 bool ColnectFetcher::canFetch(int type) const {
-  return type == Data::Collection::Coin || type == Data::Collection::Stamp;
+  return type == Data::Collection::Coin
+      || type == Data::Collection::Stamp
+      || type == Data::Collection::Card
+      || type == Data::Collection::ComicBook
+      || type == Data::Collection::Game;
 }
 
 void ColnectFetcher::readConfigHook(const KConfigGroup& config_) {
@@ -92,6 +102,10 @@ void ColnectFetcher::readConfigHook(const KConfigGroup& config_) {
     m_locale = k.toLower();
   }
   Q_ASSERT_X(m_locale.length() == 2, "ColnectFetcher::readConfigHook", "lang should be 2 char short iso");
+  const int imageSize = config_.readEntry("Image Size", -1);
+  if(imageSize > -1) {
+    m_imageSize = static_cast<ImageSize>(imageSize);
+  }
 }
 
 void ColnectFetcher::search() {
@@ -109,6 +123,15 @@ void ColnectFetcher::search() {
     case Data::Collection::Stamp:
       m_category = QStringLiteral("stamps");
       break;
+    case Data::Collection::ComicBook:
+      m_category = QStringLiteral("comics");
+      break;
+    case Data::Collection::Card:
+      m_category = QStringLiteral("sports_cards");
+      break;
+    case Data::Collection::Game:
+      m_category = QStringLiteral("video_games");
+      break;
     default:
       myWarning() << "Colnect category type not available for" << collectionType();
       stop();
@@ -217,7 +240,7 @@ Tellico::Data::EntryPtr ColnectFetcher::fetchEntryHook(uint uid_) {
       return entry;
     }
 #if 0
-    myWarning() << "Remove item debug from colnectfetcher.cpp";
+    myWarning() << "Remove item debug from colnectfetcher.cpp [colnectitemtest.json]";
     QFile file(QStringLiteral("/tmp/colnectitemtest.json"));
     if(file.open(QIODevice::WriteOnly)) {
       QTextStream t(&file);
@@ -240,6 +263,9 @@ Tellico::Data::EntryPtr ColnectFetcher::fetchEntryHook(uint uid_) {
   loadImage(entry, QStringLiteral("obverse"));
   loadImage(entry, QStringLiteral("reverse"));
   loadImage(entry, QStringLiteral("image")); // stamp image
+  loadImage(entry, QStringLiteral("cover"));
+  loadImage(entry, QStringLiteral("front"));
+  loadImage(entry, QStringLiteral("back"));
 
   // don't want to include id
   entry->setField(QStringLiteral("colnect-id"), QString());
@@ -269,12 +295,12 @@ void ColnectFetcher::slotComplete(KJob* job_) {
     stop();
     return;
   }
-  // see bug 319662. If fetcher is cancelled, job is killed
+  // see bug 319662. If fetcher is canceled, job is killed
   // if the pointer is retained, it gets double-deleted
   m_job = nullptr;
 
 #if 0
-  myWarning() << "Remove debug from colnectfetcher.cpp";
+  myWarning() << "Remove debug from colnectfetcher.cpp [colnecttest.json]";
   QFile f(QStringLiteral("/tmp/colnecttest.json"));
   if(f.open(QIODevice::WriteOnly)) {
     QTextStream t(&f);
@@ -302,10 +328,30 @@ void ColnectFetcher::slotComplete(KJob* job_) {
   m_hasMoreResults = false; // for now, no continued searches
 
   Data::CollPtr coll;
-  if(collectionType() == Data::Collection::Coin) {
-    coll = new Data::CoinCollection(true);
-  } else {
-    coll = new Data::StampCollection(true);
+  switch(collectionType()) {
+    case Data::Collection::Coin:
+      coll = new Data::CoinCollection(true);
+      break;
+    case Data::Collection::Stamp:
+      coll = new Data::StampCollection(true);
+      break;
+    case Data::Collection::ComicBook:
+      coll = new Data::ComicBookCollection(true);
+      break;
+    case Data::Collection::Card:
+      coll = new Data::CardCollection(true);
+      break;
+    case Data::Collection::Game:
+      coll = new Data::GameCollection(true);
+      break;
+    default:
+      myWarning() << "no collection pointer for type" << collectionType();
+      break;
+  }
+  Q_ASSERT(coll);
+  if(!coll) {
+    stop();
+    return;
   }
   // placeholder for colnect id, to be removed later
   Data::FieldPtr f1(new Data::Field(QStringLiteral("colnect-id"), QString()));
@@ -324,27 +370,6 @@ void ColnectFetcher::slotComplete(KJob* job_) {
     coll->addField(field);
   }
 
-  const QString mintage(QStringLiteral("mintage"));
-  if(!coll->hasField(mintage) && optionalFields().contains(mintage)) {
-    Data::FieldPtr field(new Data::Field(mintage, i18n("Mintage"), Data::Field::Number));
-    field->setCategory(i18n("General"));
-    coll->addField(field);
-  }
-
-  const QString stanleygibbons(QStringLiteral("stanley-gibbons"));
-  if(!coll->hasField(stanleygibbons) && optionalFields().contains(stanleygibbons)) {
-    Data::FieldPtr field(new Data::Field(stanleygibbons, i18nc("Stanley Gibbons stamp catalog code", "Stanley Gibbons")));
-    field->setCategory(i18n("General"));
-    coll->addField(field);
-  }
-
-  const QString michel(QStringLiteral("michel"));
-  if(!coll->hasField(michel) && optionalFields().contains(michel)) {
-    Data::FieldPtr field(new Data::Field(michel, i18nc("Michel stamp catalog code", "Michel")));
-    field->setCategory(i18n("General"));
-    coll->addField(field);
-  }
-
   // if the first item in the array is a string, probably a single item result, possibly from a Raw query
   if(!resultList.isEmpty() &&
      static_cast<QMetaType::Type>(resultList.at(0).type()) == QMetaType::QString) {
@@ -370,12 +395,23 @@ void ColnectFetcher::slotComplete(KJob* job_) {
 
     Data::EntryPtr entry(new Data::Entry(coll));
     //list action - returns array of [item_id,series_id,producer_id,front_picture_id, back_picture_id,item_description,catalog_codes,item_name]
+    // comics, title is field #7
     const QVariantList values = result.toJsonArray().toVariantList();
     entry->setField(QStringLiteral("colnect-id"), values.first().toString());
     if(optionalFields().contains(desc)) {
       entry->setField(desc, values.last().toString());
     }
-    entry->setField(QStringLiteral("year"), m_year);
+    // since card collection use a dependent field for title, fake a description with the series field
+    if(collectionType() == Data::Collection::Card) {
+      entry->setField(QStringLiteral("series"), values.at(7).toString());
+    } else {
+      entry->setField(QStringLiteral("title"), values.at(7).toString());
+    }
+    if(collectionType() == Data::Collection::ComicBook) {
+      entry->setField(QStringLiteral("pub_year"), m_year);
+    } else {
+      entry->setField(QStringLiteral("year"), m_year);
+    }
 
     FetchResult* r = new FetchResult(this, entry);
     m_entries.insert(r->uid, entry);
@@ -385,11 +421,46 @@ void ColnectFetcher::slotComplete(KJob* job_) {
   stop();
 }
 
+#define READ_AND_SET(NAME, FIELD) \
+  { \
+    const int idx = m_colnectFields.value(QStringLiteral(NAME), -1); \
+    if(idx > -1) { \
+      entry_->setField(QStringLiteral(FIELD), resultList_.at(idx).toString()); \
+    } \
+  }
+#define READ_AND_SET_OPTIONAL(NAME, FIELD) \
+  { \
+    const QString fieldName = QStringLiteral(FIELD); \
+    const int idx = m_colnectFields.value(QStringLiteral(NAME), -1); \
+    if(idx > -1 && optionalFields().contains(fieldName)) { \
+      entry_->setField(fieldName, resultList_.at(idx).toString()); \
+    } \
+  }
+#define READ_AND_SET_IMAGE(NAME, FIELD) \
+  { \
+    const int idx = m_colnectFields.value(QStringLiteral(NAME), -1); \
+    if(idx > -1) { \
+      entry_->setField(QStringLiteral(FIELD), \
+                       imageUrl(resultList_.at(0).toString(), resultList_.at(idx).toString())); \
+    } \
+  }
+#define READ_AND_SET_OPTIONAL_IMAGE(NAME, FIELD) \
+  { \
+    const QString fieldName = QStringLiteral(FIELD); \
+    const int idx = m_colnectFields.value(QStringLiteral(NAME), -1); \
+    if(idx > -1 && optionalFields().contains(fieldName)) { \
+      entry_->setField(fieldName, \
+                       imageUrl(resultList_.at(0).toString(), resultList_.at(idx).toString())); \
+    } \
+  }
+
 void ColnectFetcher::populateEntry(Data::EntryPtr entry_, const QVariantList& resultList_) {
-  if(m_colnectFields.isEmpty()) {
+  if(m_colnectFields.isEmpty() || m_lastCollType != collectionType()) {
+    m_lastCollType = collectionType();
     readDataList();
-    // set minimum size of list here
-    if(m_colnectFields.count() < 26) {
+    // set minimum size of list here (cards are 23)
+    if(m_colnectFields.count() < 23) {
+      myDebug() << "below minimum field count," << m_colnectFields.count();
       return;
     }
   }
@@ -398,62 +469,18 @@ void ColnectFetcher::populateEntry(Data::EntryPtr entry_, const QVariantList& re
     return;
   }
 
-  // lookup the field name for the list index
-  int idx = m_colnectFields.value(QStringLiteral("Issued on"), -1);
-  // the year may have already been set in the query term
-  if(m_year.isEmpty() && idx > -1) {
-    entry_->setField(QStringLiteral("year"), resultList_.at(idx).toString());
+#if 0
+  auto i = m_colnectFields.constBegin();
+  while(i != m_colnectFields.constEnd()) {
+    if(!resultList_.at(i.value()).toString().isEmpty())
+      myDebug() << i.key() << ": " << resultList_.at(i.value()).toString();
+    ++i;
   }
+#endif
 
-  idx = m_colnectFields.value(QStringLiteral("Country"), -1);
-  if(idx > -1) {
-    entry_->setField(QStringLiteral("country"), resultList_.at(idx).toString());
-  }
+  READ_AND_SET_OPTIONAL("Series", "series");
 
-  idx = m_colnectFields.value(QStringLiteral("Gum"), -1);
-  if(idx > -1) {
-    entry_->setField(QStringLiteral("gummed"), resultList_.at(idx).toString());
-  }
-
-  idx = m_colnectFields.value(QStringLiteral("Colors"), -1);
-  if(idx > -1) {
-    int colorId = resultList_.at(idx).toInt();
-    if(colorId > 0) {
-      if(m_stampColors.isEmpty()) {
-        readStampColors();
-      }
-      entry_->setField(QStringLiteral("color"), m_stampColors.value(colorId));
-    }
-  }
-
-  idx = m_colnectFields.value(QStringLiteral("Currency"), -1);
-  if(idx > -1) {
-    entry_->setField(QStringLiteral("currency"), resultList_.at(idx).toString());
-    idx = m_colnectFields.value(QStringLiteral("FaceValue"), -1);
-    if(idx > -1) {
-      // bad assumption, but go with it. First char is currency symbol
-      QString currency = entry_->field(QStringLiteral("currency"));
-      if(!currency.isEmpty()) currency.truncate(1);
-      const double value = resultList_.at(idx).toDouble();
-      // don't assume the value is in system currency
-      entry_->setField(QStringLiteral("denomination"),
-                       QLocale::system().toCurrencyString(value, currency));
-    }
-  }
-
-  idx = m_colnectFields.value(QStringLiteral("Series"), -1);
-  static const QString series(QStringLiteral("series"));
-  if(idx > -1 && optionalFields().contains(series)) {
-    entry_->setField(series, resultList_.at(idx).toString());
-  }
-
-  idx = m_colnectFields.value(QStringLiteral("Known mintage"), -1);
-  static const QString mintage(QStringLiteral("mintage"));
-  if(idx > -1 && optionalFields().contains(mintage)) {
-    entry_->setField(mintage, resultList_.at(idx).toString());
-  }
-
-  idx = m_colnectFields.value(QStringLiteral("Description"), -1);
+  int idx = m_colnectFields.value(QStringLiteral("Description"), -1);
   static const QString desc(QStringLiteral("description"));
   if(idx > -1 && optionalFields().contains(desc)) {
     static const QString name(QStringLiteral("Name"));
@@ -475,6 +502,129 @@ void ColnectFetcher::populateEntry(Data::EntryPtr entry_, const QVariantList& re
       }
     }
   }
+  switch(collectionType()) {
+    case Data::Collection::Coin:
+      populateCoinEntry(entry_, resultList_);
+      break;
+    case Data::Collection::Stamp:
+      populateStampEntry(entry_, resultList_);
+      break;
+    case Data::Collection::ComicBook:
+      populateComicEntry(entry_, resultList_);
+      break;
+    case Data::Collection::Card:
+      populateCardEntry(entry_, resultList_);
+      break;
+    case Data::Collection::Game:
+      populateGameEntry(entry_, resultList_);
+      break;
+  }
+
+  static const QString colnect(QStringLiteral("colnect"));
+  if(optionalFields().contains(colnect)) {
+    if(!entry_->collection()->hasField(colnect)) {
+      Data::FieldPtr field(new Data::Field(colnect, i18n("Colnect Link"), Data::Field::URL));
+      field->setCategory(i18n("General"));
+      entry_->collection()->addField(field);
+    }
+    QUrl link(QString::fromLatin1(COLNECT_LINK_URL));
+    const QString path(QLatin1Char('/') + m_locale +
+                       QLatin1Char('/') + m_category +
+                       QLatin1Char('/') + m_category.chopped(1) +
+                       QLatin1Char('/') + entry_->field(QStringLiteral("colnect-id")) +
+                       QLatin1Char('-') + URLize(resultList_.at(0).toString()));
+    link.setPath(link.path() + path);
+//    myDebug() << "colnect link is" << link;
+    entry_->setField(colnect, link.url());
+  }
+}
+
+void ColnectFetcher::populateCoinEntry(Data::EntryPtr entry_, const QVariantList& resultList_) {
+  auto coll = entry_->collection();
+  const QString mintage(QStringLiteral("mintage"));
+  if(!coll->hasField(mintage) && optionalFields().contains(mintage)) {
+    Data::FieldPtr field(new Data::Field(mintage, i18n("Mintage"), Data::Field::Number));
+    field->setCategory(i18n("General"));
+    coll->addField(field);
+  }
+
+  int idx = m_colnectFields.value(QStringLiteral("Issued on"), -1);
+  // the year may have already been set in the query term
+  if(m_year.isEmpty() && idx > -1) {
+    entry_->setField(QStringLiteral("year"), resultList_.at(idx).toString().left(4));
+  }
+
+  idx = m_colnectFields.value(QStringLiteral("Currency"), -1);
+  if(idx > -1) {
+    entry_->setField(QStringLiteral("currency"), resultList_.at(idx).toString());
+    idx = m_colnectFields.value(QStringLiteral("FaceValue"), -1);
+    if(idx > -1) {
+      // bad assumption, but go with it. First char is currency symbol
+      QString currency = entry_->field(QStringLiteral("currency"));
+      if(!currency.isEmpty()) currency.truncate(1);
+      const double value = resultList_.at(idx).toDouble();
+      // don't assume the value is in system currency
+      entry_->setField(QStringLiteral("denomination"),
+                       QLocale::system().toCurrencyString(value, currency));
+    }
+  }
+
+  READ_AND_SET("Country", "country");
+  READ_AND_SET_OPTIONAL("Known mintage", "mintage");
+  READ_AND_SET_OPTIONAL_IMAGE("FrontPicture", "obverse");
+  READ_AND_SET_OPTIONAL_IMAGE("BackPicture", "reverse");
+}
+
+void ColnectFetcher::populateStampEntry(Data::EntryPtr entry_, const QVariantList& resultList_) {
+  auto coll = entry_->collection();
+  const QString stanleygibbons(QStringLiteral("stanley-gibbons"));
+  if(!coll->hasField(stanleygibbons) && optionalFields().contains(stanleygibbons)) {
+    Data::FieldPtr field(new Data::Field(stanleygibbons, i18nc("Stanley Gibbons stamp catalog code", "Stanley Gibbons")));
+    field->setCategory(i18n("General"));
+    coll->addField(field);
+  }
+
+  const QString michel(QStringLiteral("michel"));
+  if(!coll->hasField(michel) && optionalFields().contains(michel)) {
+    Data::FieldPtr field(new Data::Field(michel, i18nc("Michel stamp catalog code", "Michel")));
+    field->setCategory(i18n("General"));
+    coll->addField(field);
+  }
+
+  int idx = m_colnectFields.value(QStringLiteral("Issued on"), -1);
+  // the year may have already been set in the query term
+  if(m_year.isEmpty() && idx > -1) {
+    entry_->setField(QStringLiteral("year"), resultList_.at(idx).toString().left(4));
+  }
+
+  idx = m_colnectFields.value(QStringLiteral("Currency"), -1);
+  if(idx > -1) {
+    entry_->setField(QStringLiteral("currency"), resultList_.at(idx).toString());
+    idx = m_colnectFields.value(QStringLiteral("FaceValue"), -1);
+    if(idx > -1) {
+      // bad assumption, but go with it. First char is currency symbol
+      QString currency = entry_->field(QStringLiteral("currency"));
+      if(!currency.isEmpty()) currency.truncate(1);
+      const double value = resultList_.at(idx).toDouble();
+      // don't assume the value is in system currency
+      entry_->setField(QStringLiteral("denomination"),
+                       QLocale::system().toCurrencyString(value, currency));
+    }
+  }
+
+  READ_AND_SET("Gum", "gummed");
+  READ_AND_SET("Country", "country");
+
+  idx = m_colnectFields.value(QStringLiteral("Colors"), -1);
+  if(idx > -1) {
+    const int colorId = resultList_.at(idx).toInt();
+    if(colorId > 0) {
+      if(!m_itemNames.contains("colors")) {
+        readItemNames("colors");
+      }
+      entry_->setField(QStringLiteral("color"), m_itemNames.value("colors").value(colorId));
+    }
+  }
 
   // catalog codes
   idx = m_colnectFields.value(QStringLiteral("Catalog Codes"), -1);
@@ -495,35 +645,145 @@ void ColnectFetcher::populateEntry(Data::EntryPtr entry_, const QVariantList& re
     }
   }
 
-  idx = m_colnectFields.value(QStringLiteral("FrontPicture"), -1);
+  READ_AND_SET_IMAGE("FrontPicture", "image");
+}
+
+void ColnectFetcher::populateComicEntry(Data::EntryPtr entry_, const QVariantList& resultList_) {
+  READ_AND_SET("Name", "title");
+
+  int idx = m_colnectFields.value(QStringLiteral("Issued on"), -1);
+  // the year may have already been set in the query term
+  if(m_year.isEmpty() && idx > -1) {
+    entry_->setField(QStringLiteral("pub_year"), resultList_.at(idx).toString().left(4));
+  }
+
+  static const QRegularExpression spaceCommaRx(QLatin1String("\\s*,\\s*"));
+  idx = m_colnectFields.value(QStringLiteral("Writer"), -1);
   if(idx > -1) {
-    // for coins, it's the obverse field. For stamps, it's just image
-    if(collectionType() == Data::Collection::Coin &&
-       optionalFields().contains(QStringLiteral("obverse"))) {
-      entry_->setField(QStringLiteral("obverse"),
-                       imageUrl(resultList_.at(0).toString(),
-                                resultList_.at(idx).toString()));
-    } else if(collectionType() == Data::Collection::Stamp) {
-      // always include the stamp image, no optional choice
-      entry_->setField(QStringLiteral("image"),
-                       imageUrl(resultList_.at(0).toString(),
-                                resultList_.at(idx).toString()));
+    QString writer = resultList_.at(idx).toString();
+    writer.replace(spaceCommaRx, FieldFormat::delimiterString());
+    entry_->setField(QStringLiteral("writer"), writer);
+  }
+
+  idx = m_colnectFields.value(QStringLiteral("CoverArtist"), -1);
+  if(idx > -1) {
+    QString artist = resultList_.at(idx).toString();
+    artist.replace(spaceCommaRx, FieldFormat::delimiterString());
+    entry_->setField(QStringLiteral("artist"), artist);
+  }
+
+  READ_AND_SET("Publisher", "publisher");
+  READ_AND_SET("IssuingNumber", "issue");
+  READ_AND_SET("Edition", "edition");
+  READ_AND_SET("Genre", "genre");
+  READ_AND_SET_IMAGE("FrontPicture", "cover");
+}
+
+void ColnectFetcher::populateCardEntry(Data::EntryPtr entry_, const QVariantList& resultList_) {
+  READ_AND_SET("Type", "series");
+  READ_AND_SET("Brand", "brand");
+  READ_AND_SET("Number", "number");
+  READ_AND_SET("League", "type");
+
+  int idx = m_colnectFields.value(QStringLiteral("Issued on"), -1);
+  // the year may have already been set in the query term
+  if(m_year.isEmpty() && idx > -1) {
+    entry_->setField(QStringLiteral("year"), resultList_.at(idx).toString().left(4));
+  }
+
+  idx = m_colnectFields.value(QStringLiteral("ZscCardPlayer"), -1);
+  if(idx > -1) {
+    const int playerId = resultList_.at(idx).toInt();
+    if(playerId > 0) {
+      if(!m_itemNames.contains("players")) {
+        readItemNames("players");
+      }
+      entry_->setField(QStringLiteral("player"), m_itemNames.value("players").value(playerId));
     }
   }
 
-  idx = m_colnectFields.value(QStringLiteral("BackPicture"), -1);
-  if(idx > -1 && optionalFields().contains(QStringLiteral("reverse"))) {
-    entry_->setField(QStringLiteral("reverse"),
-                     imageUrl(resultList_.at(0).toString(),
-                              resultList_.at(idx).toString()));
+  idx = m_colnectFields.value(QStringLiteral("ZscCardTeam"), -1);
+  if(idx > -1) {
+    const int teamId = resultList_.at(idx).toInt();
+    if(teamId > 0) {
+      if(!m_itemNames.contains("teams")) {
+        readItemNames("teams");
+      }
+      entry_->setField(QStringLiteral("team"), m_itemNames.value("teams").value(teamId));
+    }
+  }
+
+  READ_AND_SET_IMAGE("FrontPicture", "front");
+  READ_AND_SET_IMAGE("BackPicture", "back");
+}
+
+void ColnectFetcher::populateGameEntry(Data::EntryPtr entry_, const QVariantList& resultList_) {
+  auto coll = entry_->collection();
+  const QString pegi(QStringLiteral("pegi"));
+  if(!coll->hasField(pegi) && optionalFields().contains(pegi)) {
+    coll->addField(Data::Field::createDefaultField(Data::Field::PegiField));
+  }
+
+  READ_AND_SET("Name", "title");
+  READ_AND_SET("Publisher", "publisher");
+  READ_AND_SET("Description", "description");
+  READ_AND_SET("Genre", "genre");
+  READ_AND_SET_IMAGE("FrontPicture", "cover");
+
+  int idx = m_colnectFields.value(QStringLiteral("Console"), -1);
+  if(idx > -1) {
+    entry_->setField(QStringLiteral("platform"),
+                     Data::GameCollection::normalizePlatform(resultList_.at(idx).toString()));
+  }
+
+  idx = m_colnectFields.value(QStringLiteral("Issued on"), -1);
+  // the year may have already been set in the query term
+  if(m_year.isEmpty() && idx > -1) {
+    entry_->setField(QStringLiteral("year"), resultList_.at(idx).toString().left(4));
+  }
+
+  idx = m_colnectFields.value(QStringLiteral("Rating"), -1);
+  if(idx > -1) {
+    // can have both esrb and pegi rating
+    QStringList ratings = resultList_.at(idx).toString().split(QLatin1String("/"));
+    Q_FOREACH(QString rating, ratings) {
+      rating = rating.simplified();
+      if(rating.startsWith(QLatin1String("ESRB"))) {
+        rating = rating.mid(5);
+        Data::GameCollection::EsrbRating esrb = Data::GameCollection::UnknownEsrb;
+        if(rating == QLatin1String("U"))         esrb = Data::GameCollection::Unrated;
+        else if(rating == QLatin1String("T"))    esrb = Data::GameCollection::Teen;
+        else if(rating == QLatin1String("E"))    esrb = Data::GameCollection::Everyone;
+        else if(rating == QLatin1String("E10+")) esrb = Data::GameCollection::Everyone10;
+        else if(rating == QLatin1String("EC"))   esrb = Data::GameCollection::EarlyChildhood;
+        else if(rating == QLatin1String("A"))    esrb = Data::GameCollection::Adults;
+        else if(rating == QLatin1String("M"))    esrb = Data::GameCollection::Mature;
+        else if(rating == QLatin1String("RP"))   esrb = Data::GameCollection::Pending;
+        if(rating != Data::GameCollection::UnknownEsrb) {
+          entry_->setField(QStringLiteral("certification"), Data::GameCollection::esrbRating(esrb));
+        }
+      } else if(rating.startsWith(QLatin1String("PEGI")) && optionalFields().contains(QStringLiteral("pegi"))) {
+        static const QRegularExpression pegiRx(QStringLiteral("^PEGI \\d\\d?"));
+        auto pegiMatch = pegiRx.match(rating);
+        if(pegiMatch.hasMatch()) {
+          entry_->setField(QStringLiteral("pegi"), pegiMatch.captured(0));
+        }
+      }
+    }
   }
 }
 
+#undef READ_AND_SET
+#undef READ_AND_SET_OPTIONAL
+#undef READ_AND_SET_IMAGE
+#undef READ_AND_SET_OPTIONAL_IMAGE
+
 void ColnectFetcher::loadImage(Data::EntryPtr entry_, const QString& fieldName_) {
   const QString image = entry_->field(fieldName_);
   if(image.contains(QLatin1Char('/'))) {
     const QString id = ImageFactory::addImage(QUrl::fromUserInput(image), true /* quiet */);
     if(id.isEmpty()) {
+      myDebug() << "Failed to load" << image;
       message(i18n("The cover image could not be loaded."), MessageHandler::Warning);
     }
     // empty image ID is ok
@@ -545,6 +805,7 @@ QString ColnectFetcher::defaultIcon() {
 
 Tellico::StringHash ColnectFetcher::allOptionalFields() {
   StringHash hash;
+  hash[QStringLiteral("colnect")] = i18n("Colnect Link");
   // treat images as optional since Colnect doesn't break out different images for each year
   hash[QStringLiteral("obverse")] = i18n("Obverse");
   hash[QStringLiteral("reverse")] = i18n("Reverse");
@@ -554,6 +815,7 @@ Tellico::StringHash ColnectFetcher::allOptionalFields() {
   hash[QStringLiteral("description")] = i18n("Description");
   hash[QStringLiteral("stanley-gibbons")] = i18nc("Stanley Gibbons stamp catalog code", "Stanley Gibbons");
   hash[QStringLiteral("michel")] = i18nc("Michel stamp catalog code", "Michel");
+  hash[QStringLiteral("pegi")] = i18n("PEGI Rating");
   return hash;
 }
 
@@ -578,11 +840,13 @@ QString ColnectFetcher::URLize(const QString& name_) {
 }
 
 QString ColnectFetcher::imageUrl(const QString& name_, const QString& id_) {
+  if(m_imageSize == NoImage) return QString();
   const QString nameSlug = URLize(name_);
   const int id = id_.toInt();
   QUrl u(QString::fromLatin1(COLNECT_IMAGE_URL));
   // uses 't' for thumbnail, use 'f' for full-size
-  u.setPath(QString::fromLatin1("/t/%1/%2/%3.jpg")
+  u.setPath(QString::fromLatin1("/%1/%2/%3/%4.jpg")
+                           .arg(m_imageSize == SmallImage ? QLatin1Char('t') : QLatin1Char('f'))
                            .arg(id / 1000)
                            .arg(id % 1000, 3, 10, QLatin1Char('0'))
                            .arg(nameSlug));
@@ -597,7 +861,6 @@ void ColnectFetcher::readDataList() {
   QString query(QLatin1Char('/') + m_locale + QStringLiteral("/fields/cat/") + m_category + QLatin1Char('/'));
   u.setPath(u.path() + query);
 
-//  myDebug() << "Reading" << u;
   const QByteArray data = FileHandler::readDataFile(u, true);
   QJsonDocument doc = QJsonDocument::fromJson(data);
   if(doc.isNull()) {
@@ -614,37 +877,35 @@ void ColnectFetcher::readDataList() {
     m_colnectFields.insert(resultList.at(i).toString(), i);
 //    if(i == 5) myDebug() << m_colnectFields;
   }
-//  myDebug() << "Number of Colnect fields:" << m_colnectFields.count();
+//  myDebug() << "Colnect fields:" << m_colnectFields;
 }
 
-void ColnectFetcher::readStampColors() {
+void ColnectFetcher::readItemNames(const QByteArray& item_) {
   QUrl u(QString::fromLatin1(COLNECT_API_URL));
   // Colnect API calls are encoded as a path
-  QString query(QLatin1Char('/') + m_locale + QStringLiteral("/colors/cat/") + m_category + QLatin1Char('/'));
+  QString query(QLatin1Char('/') + m_locale + QLatin1Char('/') + QLatin1String(item_) + QStringLiteral("/cat/") + m_category + QLatin1Char('/'));
   u.setPath(u.path() + query);
 
-//  myDebug() << "Reading stamp colors from" << u;
   const QByteArray data = FileHandler::readDataFile(u, true);
   QJsonDocument doc = QJsonDocument::fromJson(data);
   if(doc.isNull()) {
-    myDebug() << "null JSON document in colnect fields";
+    myDebug() << "null JSON document in colnect results";
     return;
   }
   QJsonArray resultList = doc.array();
   if(resultList.isEmpty()) {
-    myDebug() << "no stamp color results";
+    myDebug() << "no item results";
     return;
   }
-  m_stampColors.clear();
+  QHash<int, QString> itemNames;
   for(int i = 0; i < resultList.size(); ++i) {
-    // an array of arrays, first value is id, second is color name
+    // an array of arrays, first value is id, second is name
     const QJsonArray values = resultList.at(i).toArray();
     if(values.size() > 2) {
-      m_stampColors.insert(values.at(0).toInt(), values.at(1).toString());
-//      if(i == 5) myDebug() << resultList.at(i) << m_stampColors;
+      itemNames.insert(values.at(0).toInt(), values.at(1).toString());
     }
   }
-//  myDebug() << "Number of stamp colors:" << m_stampColors.count();
+  m_itemNames.insert(item_, itemNames);
 }
 
 ColnectFetcher::ConfigWidget::ConfigWidget(QWidget* parent_, const ColnectFetcher* fetcher_)
@@ -683,6 +944,16 @@ ColnectFetcher::ConfigWidget::ConfigWidget(QWidget* parent_, const ColnectFetche
   l->addWidget(m_langCombo, row, 1);
   label->setBuddy(m_langCombo);
 
+  label = new QLabel(i18n("&Image size: "), optionsWidget());
+  l->addWidget(label, ++row, 0);
+  m_imageCombo = new GUI::ComboBox(optionsWidget());
+  m_imageCombo->addItem(i18n("No Image"), NoImage);
+  m_imageCombo->addItem(i18n("Small Image"), SmallImage);
+  m_imageCombo->addItem(i18n("Large Image"), LargeImage);
+  connect(m_imageCombo, activatedInt, this, &ConfigWidget::slotSetModified);
+  l->addWidget(m_imageCombo, row, 1);
+  label->setBuddy(m_imageCombo);
+
   l->setRowStretch(++row, 10);
 
   // now add additional fields widget
@@ -695,6 +966,7 @@ ColnectFetcher::ConfigWidget::ConfigWidget(QWidget* parent_, const ColnectFetche
       m_langCombo->addItem(fetcher_->m_locale, fetcher_->m_locale);
       m_langCombo->setCurrentIndex(m_langCombo->count()-1);
     }
+    m_imageCombo->setCurrentData(fetcher_->m_imageSize);
   }
 }
 
@@ -705,6 +977,9 @@ void ColnectFetcher::ConfigWidget::saveConfigHook(KConfigGroup& config_) {
     lang = m_langCombo->currentText();
   }
   config_.writeEntry("Locale", lang);
+
+  const int n = m_imageCombo->currentData().toInt();
+  config_.writeEntry("Image Size", n);
 }
 
 QString ColnectFetcher::ConfigWidget::preferredName() const {
