@@ -109,7 +109,10 @@ enum Type {
   TVmaze,
   UPCItemDb,
   TheTVDB,
-  RPGGeek
+  RPGGeek,
+  GamingHistory,
+  FilmAffinity,
+  Itunes
 };
 
   }
