@@ -1,5 +1,5 @@
 /***************************************************************************
-    Copyright (C) 2005-2009 Robby Stephenson <robby@periapsis.org>
+    Copyright (C) 2005-2022 Robby Stephenson <robby@periapsis.org>
  ***************************************************************************/
 
 /***************************************************************************
@@ -32,7 +32,6 @@
 #include <KSharedConfig>
 #include <KConfigGroup>
 #include <KIO/Global>
-#include <KIO/SlaveConfig>
 #include <kio_version.h>
 #if KIO_VERSION >= QT_VERSION_CHECK(5,19,0)
 #include <KIO/FavIconRequestJob>
@@ -83,25 +82,6 @@ void Fetcher::startSearch(const FetchRequest& request_) {
     return;
   }
 
-  if(needsUserAgent()) {
-    // copied from KProtocolManager::userAgentForHost
-    const QString sendUserAgent = KIO::SlaveConfig::self()->configData(QStringLiteral("http"),
-                                                                       QString(), // host name
-                                                                       QStringLiteral("SendUserAgent")).toLower();
-    if(sendUserAgent == QLatin1String("false")) {
-      myDebug() << "Fetcher - Need user agent for" << source();
-      // TODO: I'd like to link to kcmshell5 useragent as the Konqueror about page does
-      // but KIO complains about unable to open exec links
-//      message(i18n("<html>%1 requires the network request to include identification.\n"
-//                   "Check the network configuration in <a href=\"%2\">KDE System Settings</a>.</html>", source(), QStringLiteral("exec:/kcmshell5 useragent")),
-      message(i18n("%1 requires the network request to include identification.\n"
-                   "Check the network configuration in KDE System Settings.", source()),
-              MessageHandler::Error);
-      emit signalDone(this);
-      return;
-    }
-  }
-
   m_entries.clear();
   search();
 }
@@ -186,12 +166,6 @@ void Fetcher::message(const QString& message_, int type_) const {
   }
 }
 
-void Fetcher::infoList(const QString& message_, const QStringList& list_) const {
-  if(m_messager) {
-    m_messager->infoList(message_, list_);
-  }
-}
-
 QString Fetcher::favIcon(const char* url_) {
   return favIcon(QUrl(QString::fromLatin1(url_)));
 }
