@@ -71,10 +71,6 @@ public:
    */
   virtual bool canSearch(FetchKey key) const = 0;
   virtual bool canUpdate() const;
-  /**
-   * Returns true if the fetcher requires a user agent to be sent
-   */
-  virtual bool needsUserAgent() const { return false; }
 
   /**
    * Returns the type of the data source.
@@ -125,7 +121,6 @@ public:
   /**
    */
   void message(const QString& message, int type) const;
-  void infoList(const QString& message, const QStringList& list) const;
 
   /**
    * Reads the config for the widget, given a config group.
