@@ -76,6 +76,9 @@
 #include "upcitemdbfetcher.h"
 #include "thetvdbfetcher.h"
 #include "rpggeekfetcher.h"
+#include "gaminghistoryfetcher.h"
+#include "filmaffinityfetcher.h"
+#include "itunesfetcher.h"
 
 /**
  * Ideally, I'd like these initializations to be in each cpp file for each collection type
@@ -130,6 +133,9 @@ Tellico::Fetch::FetcherInitializer::FetcherInitializer() {
   RegisterFetcher<Fetch::UPCItemDbFetcher> registerUPCItemDb(UPCItemDb);
   RegisterFetcher<Fetch::TheTVDBFetcher> registerTheTVDB(TheTVDB);
   RegisterFetcher<Fetch::RPGGeekFetcher> registerRPGGeek(RPGGeek);
+  RegisterFetcher<Fetch::GamingHistoryFetcher> registerGamingHistory(GamingHistory);
+  RegisterFetcher<Fetch::FilmAffinityFetcher> registerFilmAffinity(FilmAffinity);
+  RegisterFetcher<Fetch::ItunesFetcher> registerItunes(Itunes);
 
 // these data sources depend on being able to import bibtex
 #ifdef ENABLE_BTPARSE
