@@ -166,13 +166,13 @@ void IBSFetcher::slotComplete(KJob*) {
 #endif
 
   QString s = Tellico::decodeHTML(data);
-  QRegularExpression itemRx(QLatin1String("<div class=\"cc-product-list-item.*?>(.+?)<!--"),
-                            QRegularExpression::DotMatchesEverythingOption);
-  QRegularExpression titleRx(QStringLiteral("<div class=\"cc-content-title\">\\s*<a [^>]*href=\"(.+?)\"[^>]*?>(.+?)</a"),
-                             QRegularExpression::DotMatchesEverythingOption);
-  QRegularExpression yearRx(QLatin1String("<span class=\"cc-owner\">.*?([12]\\d{3}).*?</"),
-                            QRegularExpression::DotMatchesEverythingOption);
-  QRegularExpression tagRx(QLatin1String("<.*?>"));
+  static const QRegularExpression itemRx(QLatin1String("<div class=\"cc-product-list-item.*?>(.+?)<!--"),
+                                         QRegularExpression::DotMatchesEverythingOption);
+  static const QRegularExpression titleRx(QStringLiteral("<a [^>]*href=\"(.+?)\"[^>]*?class=\"cc-title\">(.+?)</a"),
+                                          QRegularExpression::DotMatchesEverythingOption);
+  static const QRegularExpression yearRx(QLatin1String("<span class=\"cc-publisher\">.*?([12]\\d{3}).*?</"),
+                                         QRegularExpression::DotMatchesEverythingOption);
+  static const QRegularExpression tagRx(QLatin1String("<.*?>"));
 
   QString url, title, year;
   auto matchIterator = itemRx.globalMatch(s);
