@@ -149,7 +149,10 @@ const Tellico::Data::Image& ImageFactory::addImageImpl(const QUrl& url_, bool qu
   }
 
   const Data::Image& img = job->image();
-  Q_ASSERT(!img.isNull());
+  if(img.isNull()) {
+    myDebug() << "Null image for" << url_.toDisplayString();
+    return Data::Image::null;
+  }
 
   // hold the image in memory since it probably isn't written locally to disk yet
   if(!d->imageDict.contains(img.id())) {
@@ -726,6 +729,7 @@ void ImageFactory::setLocalDirectory(const QUrl& url_) {
 }
 
 void ImageFactory::setZipArchive(std::unique_ptr<KZip> zip_) {
+  Q_ASSERT(factory && "ImageFactory is not initialized!");
   if(!zip_) {
     return;
   }
