@@ -53,6 +53,9 @@
 #include "translators/boardgamegeekimporter.h"
 #include "translators/librarythingimporter.h"
 #include "translators/collectorzimporter.h"
+#include "translators/datacrowimporter.h"
+#include "translators/marcimporter.h"
+#include "translators/ebookimporter.h"
 #include "utils/datafileregistry.h"
 
 #include <KLocalizedString>
@@ -316,6 +319,20 @@ Tellico::Import::Importer* ImportDialog::importer(Tellico::Import::Format format
       CHECK_SIZE;
       importer = new Import::CollectorzImporter(firstURL);
       break;
+
+    case Import::DataCrow:
+      CHECK_SIZE;
+      importer = new Import::DataCrowImporter(firstURL);
+      break;
+
+    case Import::MARC:
+      CHECK_SIZE;
+      importer = new Import::MarcImporter(firstURL);
+      break;
+
+    case Import::EBook:
+      importer = new Import::EBookImporter(urls_);
+      break;
   }
   if(!importer) {
     myWarning() << "importer not created!";
@@ -369,6 +386,7 @@ QString ImportDialog::fileFilter(Tellico::Import::Format format_) {
     case Import::Delicious:
     case Import::Griffith:
     case Import::Collectorz:
+    case Import::DataCrow:
       text = i18n("XML Files") + QLatin1String(" (*.xml)") + QLatin1String(";;");
       break;
 
@@ -401,6 +419,11 @@ QString ImportDialog::fileFilter(Tellico::Import::Format format_) {
       text += i18n("XML Files") + QLatin1String(" (*.xml)") + QLatin1String(";;");
       break;
 
+    case Import::EBook:
+      // KFileMetaData has extractors that support mimetypes with these typical extensions
+      text = i18n("eBook Files") + QLatin1String(" (*.epub *.fb2 *.fb2zip *.mobi)") + QLatin1String(";;");
+      break;
+
     case Import::AudioFile:
     case Import::Alexandria:
     case Import::FreeDB:
@@ -409,6 +432,7 @@ QString ImportDialog::fileFilter(Tellico::Import::Format format_) {
     case Import::Goodreads:
     case Import::BoardGameGeek:
     case Import::LibraryThing:
+    case Import::MARC:
       break;
   }
 
@@ -460,24 +484,27 @@ void ImportDialog::slotUpdateAction() {
 
 // static
 Tellico::Data::CollPtr ImportDialog::importURL(Tellico::Import::Format format_, const QUrl& url_) {
-  Import::Importer* imp = importer(format_, QList<QUrl>() << url_);
+  QScopedPointer<Import::Importer> imp(importer(format_, QList<QUrl>() << url_));
   if(!imp) {
     return Data::CollPtr();
   }
 
-  ProgressItem& item = ProgressManager::self()->newProgressItem(imp, imp->progressLabel(), true);
-  connect(imp, &Import::Importer::signalTotalSteps,
-          ProgressManager::self(), &ProgressManager::setTotalSteps);
-  connect(imp, &Import::Importer::signalProgress,
-          ProgressManager::self(), &ProgressManager::setProgress);
-  connect(&item, &ProgressItem::signalCancelled, imp, &Import::Importer::slotCancel);
-  ProgressItem::Done done(imp);
+  Data::CollPtr c;
+  {
+    // do this in a block to ensure the progress item is deleted before the importer
+    ProgressItem& item = ProgressManager::self()->newProgressItem(imp.data(), imp->progressLabel(), true);
+    connect(imp.data(), &Import::Importer::signalTotalSteps,
+            ProgressManager::self(), &ProgressManager::setTotalSteps);
+    connect(imp.data(), &Import::Importer::signalProgress,
+            ProgressManager::self(), &ProgressManager::setProgress);
+    connect(&item, &ProgressItem::signalCancelled, imp.data(), &Import::Importer::slotCancel);
+    ProgressItem::Done done(imp.data());
 
-  Data::CollPtr c = imp->collection();
+    c = imp->collection();
+  }
   if(!c && !imp->statusMessage().isEmpty()) {
     GUI::Proxy::sorry(imp->statusMessage());
   }
-  delete imp;
   return c;
 }
 
