@@ -145,6 +145,7 @@ int main(int argc, char* argv[]) {
   parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("bibtex"), i18n("Import <filename> as a bibtex file")));
   parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("mods"), i18n("Import <filename> as a MODS file")));
   parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("ris"), i18n("Import <filename> as a RIS file")));
+  parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("pdf"), i18n("Import <filename> as a PDF file")));
   parser.addPositionalArgument(QStringLiteral("[filename]"), i18n("File to open"));
 
   aboutData.setupCommandLine(&parser);
@@ -173,6 +174,8 @@ int main(int argc, char* argv[]) {
         format = Tellico::Import::MODS;
       } else if(parser.isSet(QStringLiteral("ris"))) {
         format = Tellico::Import::RIS;
+      } else if(parser.isSet(QStringLiteral("pdf"))) {
+        format = Tellico::Import::PDF;
       };
       if(format == Tellico::Import::TellicoXML) {
         tellico->slotFileOpen(QUrl::fromUserInput(args.at(0), QDir::currentPath()));
