@@ -68,9 +68,9 @@ void DarkHorseFetcherTest::testComic() {
   // don't sync() and save the new path
   cg.deleteEntry("ExecPath");
 
-  Tellico::Data::EntryList results = DO_FETCH1(fetcher, request, 1);
+  Tellico::Data::EntryList results = DO_FETCH(fetcher, request);
 
-  QCOMPARE(results.size(), 1);
+  QCOMPARE(results.size(), 2);
   // the first entry had better be the right one
   Tellico::Data::EntryPtr entry = results.at(0);
 
@@ -86,3 +86,36 @@ void DarkHorseFetcherTest::testComic() {
   QVERIFY(!entry->field(QSL("cover")).contains(QLatin1Char('/')));
   QVERIFY(!Tellico::ImageFactory::imageById(entry->field(QSL("cover"))).isNull());
 }
+
+void DarkHorseFetcherTest::testMasterverse() {
+  Tellico::Fetch::FetchRequest request(Tellico::Data::Collection::ComicBook, Tellico::Fetch::Title,
+                                       QSL("Masters of the Universe: Masterverse #1"));
+  Tellico::Fetch::Fetcher::Ptr fetcher(new Tellico::Fetch::ExecExternalFetcher(this));
+
+  KSharedConfig::Ptr config = KSharedConfig::openConfig(QFINDTESTDATA("../fetch/scripts/dark_horse_comics.py.spec"),
+                                                        KConfig::SimpleConfig);
+  KConfigGroup cg = config->group(QSL("<default>"));
+  cg.writeEntry("ExecPath", QFINDTESTDATA("../fetch/scripts/dark_horse_comics.py"));
+  fetcher->readConfig(cg);
+  // don't sync() and save the new path
+  cg.deleteEntry("ExecPath");
+
+  Tellico::Data::EntryList results = DO_FETCH(fetcher, request);
+  QVERIFY(results.size() > 0);
+  Tellico::Data::EntryPtr entry;  //  results can be randomly ordered, loop until we find the one we want
+  foreach(Tellico::Data::EntryPtr testEntry, results) {
+    if(!testEntry->title().contains(QLatin1Char('('))) {
+      entry = testEntry;
+      break;
+    }
+  }
+  QVERIFY(entry);
+
+  QCOMPARE(entry->field(QSL("title")), QSL("Masters of the Universe: Masterverse #1"));
+  QCOMPARE(entry->field(QSL("pub_year")), QSL("2023"));
+  QCOMPARE(entry->field(QSL("genre")), QSL("Superhero; Action/Adventure"));
+  QCOMPARE(entry->field(QSL("pages")), QSL("32"));
+  QCOMPARE(entry->field(QSL("publisher")), QSL("Dark Horse Comics"));
+  QCOMPARE(entry->field(QSL("writer")), QSL("Tim Seeley"));
+  QCOMPARE(entry->field(QSL("artist")), QSL("Eddie Nunez; Sergio Aragonés; Kelley Jones"));
+}
