@@ -92,6 +92,8 @@ void MobyGamesFetcherTest::testTitle() {
   QVERIFY(!entry->field(QStringLiteral("description")).isEmpty());
   QVERIFY(!entry->field(QStringLiteral("cover")).isEmpty());
   QVERIFY(!entry->field(QStringLiteral("cover")).contains(QLatin1Char('/')));
+  QVERIFY(!entry->field(QStringLiteral("screenshot")).isEmpty());
+  QVERIFY(!entry->field(QStringLiteral("screenshot")).contains(QLatin1Char('/')));
 }
 
 // same search, except to include platform name in search
