@@ -678,7 +678,7 @@ bool TableColumnHandler::end(const QStringRef&, const QStringRef&) {
      d->currentField->name() == QLatin1String("track") &&
      !d->textBuffer.isEmpty() &&
      d->textBuffer.contains(FieldFormat::columnDelimiterString()) == 0) {
-    const QRegularExpression rx(QLatin1String("^\\d+:\\d\\d$"));
+    static const QRegularExpression rx(QLatin1String("^\\d+:\\d\\d$"));
     if(rx.match(d->text).hasMatch()) {
       d->text += FieldFormat::columnDelimiterString();
       d->text += d->entries.back()->field(QStringLiteral("artist"));
